==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+88"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wszystkie pliki obrazów (%1)
Wszystkie pliki (*.*)</translatorcomment>
        <translation type="unfinished">Pliki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Eksportuj jako bitmapę</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Błąd podczas generowania pliku bitmapy&apos;&amp;#39;:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Bitmap file został wywieziony do&apos;&amp;#39;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translatorcomment>--google--
Eksportuj bitmapę...</translatorcomment>
        <translation type="unfinished">Export Bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Debuguj zmianę rozmiaru
Debuguj zmianę rozmiaru
Zmienia rozmiar okna aplikacji</translatorcomment>
        <translation type="unfinished">Rozmiar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Szerokość:
&amp;Szerokość papieru:</translatorcomment>
        <translation type="unfinished">Szerokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation type="unfinished">Wysokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pikseli na jednostkę rysunku:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Marginesy:
Marginesy:</translatorcomment>
        <translation type="unfinished">Marginesy:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translatorcomment>--google--
Minimalny odstęp siatki (piksele):
Minimalny odstęp siatki (piksele)</translatorcomment>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Tło
Tło:
Tło rysunku:</translatorcomment>
        <translation type="unfinished">Tło</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation type="unfinished">Biały</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation type="unfinished">Bardzo gruby</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Bitmap Export ...</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wszystkie pliki obrazów (%1)
Wszystkie pliki (*.*)</translatorcomment>
        <translation type="unfinished">Pliki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Eksportuj jako bitmapę</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Błąd podczas generowania pliku bitmapy&apos;&amp;#39;:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Bitmap file został wywieziony do&apos;&amp;#39;</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translatorcomment>--google--
Eksportuj bitmapę...</translatorcomment>
        <translation type="unfinished">Export Bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Debuguj zmianę rozmiaru
Debuguj zmianę rozmiaru
Zmienia rozmiar okna aplikacji</translatorcomment>
        <translation type="unfinished">Rozmiar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Szerokość:
&amp;Szerokość papieru:</translatorcomment>
        <translation type="unfinished">Szerokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation type="unfinished">Wysokość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pikseli na jednostkę rysunku:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Marginesy:
Marginesy:</translatorcomment>
        <translation type="unfinished">Marginesy:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translatorcomment>--google--
Minimalny odstęp siatki (piksele):
Minimalny odstęp siatki (piksele)</translatorcomment>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Tło
Tło:
Tło rysunku:</translatorcomment>
        <translation type="unfinished">Tło</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation type="unfinished">Biały</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation type="unfinished">Bardzo gruby</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Bitmap Export ...</translation>
    </message>
</context>
</TS>
